diff Core/Toolbox.cpp @ 59:c996319e90bc orthanc-renaming

renaming in Core
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:28:56 +0200
parents a15e90e5d6fc
children de8a5329b069
line wrap: on
line diff
--- a/Core/Toolbox.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/Toolbox.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,7 +20,7 @@
 
 #include "Toolbox.h"
 
-#include "PalanthirException.h"
+#include "OrthancException.h"
 
 #include <string.h>
 #include <boost/filesystem.hpp>
@@ -39,7 +39,7 @@
 #include "../Resources/md5/md5.h"
 #include "../Resources/base64/base64.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   static bool finish;
 
@@ -125,7 +125,7 @@
     f.open(path, std::ifstream::in | std::ios::binary);
     if (!f.good())
     {
-      throw PalanthirException("Unable to open a file");
+      throw OrthancException("Unable to open a file");
     }
 
     // http://www.cplusplus.com/reference/iostream/istream/tellg/
@@ -150,7 +150,7 @@
       if (boost::filesystem::is_regular_file(path))
         boost::filesystem::remove(path);
       else
-        throw PalanthirException("The path is not a regular file: " + path);
+        throw OrthancException("The path is not a regular file: " + path);
     }
   }
 
@@ -166,7 +166,7 @@
     if (uri.size() == 0 ||
         uri[0] != URI_SEPARATOR)
     {
-      throw PalanthirException(ErrorCode_UriSyntax);
+      throw OrthancException(ErrorCode_UriSyntax);
     }
 
     // Count the number of slashes in the URI to make an assumption
@@ -301,7 +301,7 @@
     }
     catch (boost::filesystem::filesystem_error)
     {
-      throw PalanthirException(ErrorCode_InexistentFile);
+      throw OrthancException(ErrorCode_InexistentFile);
     }
   }
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium